﻿using HeuristicLab.Collections;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HeuristicLab.Problems.DataAnalysis.Implementation {
  [Item("NamedIntervals", "Represents variables with their interval ranges.")]
  [StorableClass]
  public class NamedIntervals : Item {
    ObservableDictionary<string, Interval> variableIntervals = new ObservableDictionary<string, Interval>();

    public NamedIntervals() : base(){}
    protected NamedIntervals(bool deserializing) : base(deserializing) { }
    protected NamedIntervals(NamedIntervals original, Cloner cloner) : base(original, cloner) { }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new NamedIntervals(this, cloner);
    }

    public bool InsertMany(IEnumerable<KeyValuePair<string, Interval>> entries) {
      if (entries == null) throw new ArgumentNullException("The given dataset is null.");
      if (entries.Count() != 0) {
        foreach (var entry in entries) {
          if (variableIntervals.ContainsKey(entry.Key))
            variableIntervals[entry.Key] = entry.Value;
          else
            variableIntervals.Add(entry.Key, entry.Value);
        }
      }
      return true;
    }

    public bool Add(string key, Interval value) {
      variableIntervals[key] = value;
      return true;
    }
   
  }
}

